<?php
// 设置响应头为JSON
header('Content-Type: application/json');

// 添加日志记录
error_log("ajax/get_batches.php 被调用");

// 计算项目根目录的绝对路径
$root_dir = dirname(dirname(__FILE__));

// 包含配置文件
require_once $root_dir . '/config/config.php';

// 检查数据库连接
if (!isset($conn) || $conn->connect_error) {
    error_log("数据库连接失败: " . ($conn->connect_error ?? "连接变量不存在"));
    echo json_encode(['error' => '数据库连接失败']);
    exit;
}

// 记录连接成功
error_log("数据库连接成功");

// 初始化结果数组
$result = [];

// 获取参数
$warehouseId = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : 0;
$productId = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
$batchId = isset($_GET['batch_id']) ? intval($_GET['batch_id']) : 0;

// 记录请求参数
error_log("查询批次请求参数: warehouse_id=$warehouseId, product_id=$productId, batch_id=$batchId");

try {
    // 查询批次数据 - 直接使用已经包含的 $conn
    $sql = "SELECT pb.batch_id, pb.batch_number, pb.production_date, pb.expiration_date, COALESCE(i.quantity, 0) as quantity
            FROM product_batches pb
            LEFT JOIN inventory i ON pb.batch_id = i.batch_id AND i.product_id = ? AND i.warehouse_id = ?
            WHERE (i.quantity > 0 OR (? > 0 AND pb.batch_id = ?))
            ORDER BY pb.expiration_date ASC";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param("iiii", $productId, $warehouseId, $batchId, $batchId);
    $stmt->execute();
    $res = $stmt->get_result();

    // 存储批次数据
    $batches = [];
    while ($row = $res->fetch_assoc()) {
        $batches[] = $row;
    }

    // 记录查询到的批次数量和是否包含当前选择的批次
    $containsCurrentBatch = false;
    foreach ($batches as $batch) {
        if ($batch['batch_id'] == $batchId) {
            $containsCurrentBatch = true;
            break;
        }
    }
    error_log("查询到 " . count($batches) . " 个批次，其中包含当前选中批次: " . ($containsCurrentBatch ? "是" : "否"));

    // 如果没有找到批次但提供了批次ID，直接从批次表获取该批次信息
    if (count($batches) == 0 && $batchId > 0) {
        $batchSql = "SELECT batch_id, batch_number, production_date, expiration_date, 0 as quantity 
                    FROM product_batches 
                    WHERE batch_id = ?";
        $batchStmt = $conn->prepare($batchSql);
        $batchStmt->bind_param("i", $batchId);
        $batchStmt->execute();
        $batchRes = $batchStmt->get_result();

        if ($batchRes && $batch = $batchRes->fetch_assoc()) {
            $batches[] = $batch;
            error_log("未在库存中找到批次，但从批次表中找到了批次ID " . $batchId);
        } else {
            error_log("无法找到批次ID " . $batchId . " 的信息");
        }
    }

    // 返回批次数据
    echo json_encode($batches);
} catch (Exception $e) {
    // 记录错误并返回空数组
    error_log("获取批次时发生错误: " . $e->getMessage());
    echo json_encode([]);
}
