<?php
// 确保用户已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 引入配置文件和函数库
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 使用全局变量$conn
// 获取筛选参数
$periodType = isset($_GET['periodType']) ? $_GET['periodType'] : 'month';
$periodDate = isset($_GET['periodDate']) ? $_GET['periodDate'] : date('Y-m-01');
$sortBy = isset($_GET['sortBy']) ? $_GET['sortBy'] : 'report_date';
$sortOrder = isset($_GET['sortOrder']) ? $_GET['sortOrder'] : 'DESC';

// 验证日期格式
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $periodDate)) {
    $periodDate = date('Y-m-01');
}

// 构建排序字段
$sortField = '';
switch ($sortBy) {
    case 'total_sales':
        $sortField = 'total_sales';
        break;
    case 'total_cost':
        $sortField = 'total_cost';
        break;
    case 'gross_profit':
        $sortField = 'gross_profit';
        break;
    case 'net_profit':
        $sortField = 'net_profit';
        break;
    case 'report_date':
        $sortField = 'report_date';
        break;
    default:
        $sortField = 'report_date';
}

// 构建查询条件
$whereClause = 'period_type = ? AND report_date = ?';
$queryParams = [$periodType, $periodDate];
$paramTypes = 'ss';

// 分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 构建财务报表数据查询
$sql = "SELECT * FROM financial_reports 
        WHERE $whereClause
        ORDER BY $sortField $sortOrder
        LIMIT ?, ?";

// 添加分页参数
$queryParams[] = $offset;
$queryParams[] = $limit;
$paramTypes .= 'ii';

// 执行数据查询
$stmt = $conn->prepare($sql);
if (!$stmt) {
    $error = "准备查询时出错: " . $conn->error;
} else {
    $stmt->bind_param($paramTypes, ...$queryParams);
    $stmt->execute();
    $result = $stmt->get_result();
    $financialData = [];

    while ($row = $result->fetch_assoc()) {
        $financialData[] = $row;
    }

    $stmt->close();
}

// 获取汇总数据
$summarySql = "SELECT 
               AVG(total_sales) as avg_sales,
               AVG(total_cost) as avg_cost,
               AVG(gross_profit) as avg_gross_profit,
               AVG(gross_profit_rate) as avg_gross_profit_rate,
               AVG(net_profit) as avg_net_profit,
               AVG(net_profit_rate) as avg_net_profit_rate,
               AVG(receivables) as avg_receivables,
               AVG(payables) as avg_payables,
               AVG(inventory_value) as avg_inventory,
               AVG(cash_flow) as avg_cash_flow
               FROM financial_reports
               WHERE period_type = ? AND report_date = ?";
$summaryStmt = $conn->prepare($summarySql);
$summaryData = [];

if ($summaryStmt) {
    $summaryStmt->bind_param('ss', $periodType, $periodDate);
    $summaryStmt->execute();
    $summaryResult = $summaryStmt->get_result();
    $summaryData = $summaryResult->fetch_assoc();
    $summaryStmt->close();
}

// 获取上一周期的财务数据进行比较
$previousPeriodDate = '';
if ($periodType == 'month') {
    $previousPeriodDate = date('Y-m-01', strtotime("$periodDate -1 month"));
} elseif ($periodType == 'year') {
    $previousPeriodDate = date('Y-01-01', strtotime("$periodDate -1 year"));
} else {
    $previousPeriodDate = date('Y-m-d', strtotime("$periodDate -7 days"));
}

$lastPeriodSql = "SELECT 
                  AVG(total_sales) as last_avg_sales,
                  AVG(net_profit) as last_avg_profit
                  FROM financial_reports
                  WHERE period_type = ? AND report_date = ?";
$lastPeriodStmt = $conn->prepare($lastPeriodSql);
$lastPeriodData = [];

if ($lastPeriodStmt) {
    $lastPeriodStmt->bind_param('ss', $periodType, $previousPeriodDate);
    $lastPeriodStmt->execute();
    $lastPeriodResult = $lastPeriodStmt->get_result();
    $lastPeriodData = $lastPeriodResult->fetch_assoc();
    $lastPeriodStmt->close();
}

// 计算环比增长率
$salesGrowthRate = 0;
$profitGrowthRate = 0;

if (!empty($lastPeriodData)) {
    if ($lastPeriodData['last_avg_sales'] > 0) {
        $salesGrowthRate = ($summaryData['avg_sales'] - $lastPeriodData['last_avg_sales']) / $lastPeriodData['last_avg_sales'] * 100;
    }

    if ($lastPeriodData['last_avg_profit'] > 0) {
        $profitGrowthRate = ($summaryData['avg_net_profit'] - $lastPeriodData['last_avg_profit']) / $lastPeriodData['last_avg_profit'] * 100;
    }
}

// 查询总记录数
$countSql = "SELECT COUNT(*) as total FROM financial_reports WHERE $whereClause";
$countStmt = $conn->prepare($countSql);
$totalRecords = 0;
$totalPages = 0;

if ($countStmt) {
    $countStmt->bind_param(substr($paramTypes, 0, 2), $periodType, $periodDate);
    $countStmt->execute();
    $countResult = $countStmt->get_result();
    $row = $countResult->fetch_assoc();
    $totalRecords = $row['total'];
    $totalPages = ceil($totalRecords / $limit);
    $countStmt->close();
}

// 格式化日期显示
function formatPeriodDate($date, $type)
{
    if ($type == 'month') {
        return date('Y年m月', strtotime($date));
    } elseif ($type == 'year') {
        return date('Y年', strtotime($date));
    } else {
        return date('Y年m月d日', strtotime($date));
    }
}

// 构建分页URL
function buildPageUrl($page)
{
    $params = $_GET;
    $params['page'] = $page;
    return '?' . http_build_query($params);
}

// 构建排序链接
function getSortLink($field, $currentSortBy, $currentSortOrder)
{
    $params = $_GET;
    $params['sortBy'] = $field;
    $params['sortOrder'] = ($currentSortBy == $field && $currentSortOrder == 'ASC') ? 'DESC' : 'ASC';
    return '?' . http_build_query($params);
}

// 释放数据库连接
$conn->close();
?>

<div class="analysis-container">
    <!-- 查询筛选表单 -->
    <div class="filter-container">
        <form id="filterForm" method="GET" action="index.php">
            <input type="hidden" name="page" value="financial">

            <div class="filter-group">
                <label for="periodType">统计周期:</label>
                <select name="periodType" id="periodType" class="filter-select">
                    <option value="day" <?php echo $periodType == 'day' ? 'selected' : ''; ?>>日</option>
                    <option value="month" <?php echo $periodType == 'month' ? 'selected' : ''; ?>>月</option>
                    <option value="year" <?php echo $periodType == 'year' ? 'selected' : ''; ?>>年</option>
                </select>
            </div>

            <div class="filter-group">
                <label for="periodDate">日期:</label>
                <input type="date" name="periodDate" id="periodDate" value="<?php echo $periodDate; ?>" class="filter-input">
            </div>

            <div class="filter-group">
                <label for="sortBy">排序字段:</label>
                <select name="sortBy" id="sortBy" class="filter-select">
                    <option value="report_date" <?php echo $sortBy == 'report_date' ? 'selected' : ''; ?>>日期</option>
                    <option value="total_sales" <?php echo $sortBy == 'total_sales' ? 'selected' : ''; ?>>销售额</option>
                    <option value="total_cost" <?php echo $sortBy == 'total_cost' ? 'selected' : ''; ?>>成本</option>
                    <option value="gross_profit" <?php echo $sortBy == 'gross_profit' ? 'selected' : ''; ?>>毛利</option>
                    <option value="net_profit" <?php echo $sortBy == 'net_profit' ? 'selected' : ''; ?>>净利润</option>
                </select>
            </div>

            <div class="filter-group">
                <label for="sortOrder">排序方式:</label>
                <select name="sortOrder" id="sortOrder" class="filter-select">
                    <option value="DESC" <?php echo $sortOrder == 'DESC' ? 'selected' : ''; ?>>降序</option>
                    <option value="ASC" <?php echo $sortOrder == 'ASC' ? 'selected' : ''; ?>>升序</option>
                </select>
            </div>

            <div class="filter-group">
                <button type="submit" class="btn btn-primary">查询</button>
            </div>
        </form>
    </div>

    <!-- 财务概览 -->
    <div class="analysis-dashboard">
        <h3><?php echo formatPeriodDate($periodDate, $periodType); ?>财务概览</h3>

        <div class="analysis-overview">
            <div class="stat-card">
                <div class="stat-title">平均销售额</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_sales'] ?? 0, 2); ?></div>
                <div class="stat-change <?php echo $salesGrowthRate >= 0 ? 'positive' : 'negative'; ?>">
                    <?php echo ($salesGrowthRate >= 0 ? '+' : '') . number_format($salesGrowthRate, 2); ?>%
                </div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均成本</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_cost'] ?? 0, 2); ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均毛利</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_gross_profit'] ?? 0, 2); ?></div>
                <div class="stat-extra"><?php echo number_format($summaryData['avg_gross_profit_rate'] ?? 0, 2); ?>%</div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均净利润</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_net_profit'] ?? 0, 2); ?></div>
                <div class="stat-change <?php echo $profitGrowthRate >= 0 ? 'positive' : 'negative'; ?>">
                    <?php echo ($profitGrowthRate >= 0 ? '+' : '') . number_format($profitGrowthRate, 2); ?>%
                </div>
                <div class="stat-extra"><?php echo number_format($summaryData['avg_net_profit_rate'] ?? 0, 2); ?>%</div>
            </div>
        </div>

        <div class="analysis-overview">
            <div class="stat-card">
                <div class="stat-title">平均应收账款</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_receivables'] ?? 0, 2); ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均应付账款</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_payables'] ?? 0, 2); ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均库存价值</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_inventory'] ?? 0, 2); ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-title">平均现金流</div>
                <div class="stat-value"><?php echo number_format($summaryData['avg_cash_flow'] ?? 0, 2); ?></div>
            </div>
        </div>
    </div>

    <!-- 财务报表数据 -->
    <div class="data-section">
        <h3>财务报表详细数据</h3>

        <?php if (empty($financialData)): ?>
            <div class="alert alert-info">没有找到符合条件的财务数据</div>
        <?php else: ?>
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表日期</th>
                            <th>
                                <a href="<?php echo getSortLink('total_sales', $sortBy, $sortOrder); ?>">
                                    销售额 <?php echo ($sortBy == 'total_sales') ? ($sortOrder == 'ASC' ? '↑' : '↓') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('total_cost', $sortBy, $sortOrder); ?>">
                                    成本 <?php echo ($sortBy == 'total_cost') ? ($sortOrder == 'ASC' ? '↑' : '↓') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('gross_profit', $sortBy, $sortOrder); ?>">
                                    毛利 <?php echo ($sortBy == 'gross_profit') ? ($sortOrder == 'ASC' ? '↑' : '↓') : ''; ?>
                                </a>
                            </th>
                            <th>毛利率</th>
                            <th>运营费用</th>
                            <th>
                                <a href="<?php echo getSortLink('net_profit', $sortBy, $sortOrder); ?>">
                                    净利润 <?php echo ($sortBy == 'net_profit') ? ($sortOrder == 'ASC' ? '↑' : '↓') : ''; ?>
                                </a>
                            </th>
                            <th>净利率</th>
                            <th>应收款</th>
                            <th>应付款</th>
                            <th>库存价值</th>
                            <th>现金流</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($financialData as $report): ?>
                            <tr>
                                <td><?php echo formatPeriodDate($report['report_date'], $report['period_type']); ?></td>
                                <td class="amount"><?php echo number_format($report['total_sales'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['total_cost'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['gross_profit'], 2); ?></td>
                                <td class="rate"><?php echo number_format($report['gross_profit_rate'], 2); ?>%</td>
                                <td class="amount"><?php echo number_format($report['operating_expenses'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['net_profit'], 2); ?></td>
                                <td class="rate"><?php echo number_format($report['net_profit_rate'], 2); ?>%</td>
                                <td class="amount"><?php echo number_format($report['receivables'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['payables'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['inventory_value'], 2); ?></td>
                                <td class="amount"><?php echo number_format($report['cash_flow'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页导航 -->
            <?php if ($totalPages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="<?php echo buildPageUrl(1); ?>" class="pagination-item">首页</a>
                        <a href="<?php echo buildPageUrl($page - 1); ?>" class="pagination-item">上一页</a>
                    <?php endif; ?>

                    <?php
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $page + 2);

                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <a href="<?php echo buildPageUrl($i); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
                    <?php endfor; ?>

                    <?php if ($page < $totalPages): ?>
                        <a href="<?php echo buildPageUrl($page + 1); ?>" class="pagination-item">下一页</a>
                        <a href="<?php echo buildPageUrl($totalPages); ?>" class="pagination-item">末页</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    </div>
</div>

<style>
    .analysis-container {
        padding: 20px;
        background-color: #f9f9f9;
    }

    .filter-container {
        background-color: #fff;
        padding: 15px;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    #filterForm {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .filter-group {
        display: flex;
        flex-direction: column;
        min-width: 150px;
    }

    .filter-select,
    .filter-input {
        padding: 8px 10px;
        border: 1px solid #ddd;
        border-radius: 4px;
        font-size: 14px;
    }

    .analysis-dashboard {
        margin-bottom: 30px;
    }

    .analysis-overview {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        padding: 15px;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 200px;
    }

    .stat-title {
        color: #666;
        font-size: 14px;
        margin-bottom: 5px;
    }

    .stat-value {
        font-size: 24px;
        font-weight: bold;
        color: #333;
    }

    .stat-change {
        font-size: 14px;
        margin-top: 5px;
    }

    .stat-change.positive {
        color: #28a745;
    }

    .stat-change.negative {
        color: #dc3545;
    }

    .stat-extra {
        font-size: 14px;
        color: #666;
        margin-top: 5px;
    }

    .data-section {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f5f5f5;
        font-weight: 600;
    }

    .data-table th a {
        color: #333;
        text-decoration: none;
    }

    .data-table .amount {
        text-align: right;
    }

    .data-table .rate {
        text-align: center;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .pagination {
        display: flex;
        justify-content: center;
        margin-top: 20px;
    }

    .pagination-item {
        padding: 8px 12px;
        margin: 0 5px;
        border-radius: 4px;
        background-color: #f5f5f5;
        color: #333;
        text-decoration: none;
    }

    .pagination-item.active {
        background-color: #007bff;
        color: #fff;
    }

    /* 响应式设计 */
    @media (max-width: 768px) {
        .analysis-overview {
            flex-direction: column;
        }

        .stat-card {
            min-width: 100%;
        }

        #filterForm {
            flex-direction: column;
        }

        .filter-group {
            width: 100%;
        }
    }
</style>