<?php
// 在文件开头添加更详细的日志
error_log('get_batches.php 被直接访问，请求参数：' . json_encode($_GET));

// 设置响应类型为JSON
header('Content-Type: application/json; charset=utf-8');

// 设置时区
date_default_timezone_set('Asia/Shanghai');

// 引入配置文件，其中包含数据库连接
require_once '../../../config/config.php';

// 记录请求以便调试
error_log('AJAX请求: get_batches.php 被调用，参数: ' . json_encode($_GET));

// 初始化响应数组
$response = [
    'success' => false,
    'batches' => [],
    'message' => ''
];

try {
    // 获取请求参数
    $warehouseId = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : 0;
    $productId = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
    $batchId = isset($_GET['batch_id']) ? intval($_GET['batch_id']) : 0;

    error_log("获取批次 - 仓库ID: $warehouseId, 商品ID: $productId, 批次ID: $batchId");

    // 验证必要参数
    if (!$productId) {
        throw new Exception('缺少必要参数: 商品ID');
    }

    // 检查数据库连接
    if (!isset($conn) || $conn->connect_error) {
        throw new Exception("数据库连接失败: " . ($conn->connect_error ?? "连接变量未设置"));
    }

    // 简化SQL查询 - 直接查询批次和库存
    $sql = "SELECT 
                pb.batch_id, 
                pb.batch_number, 
                pb.production_date, 
                pb.expiration_date, 
                COALESCE(inv.quantity, 0) AS available_quantity
            FROM 
                product_batches pb 
            LEFT JOIN 
                inventory inv ON pb.batch_id = inv.batch_id AND inv.product_id = ? ";

    // 添加仓库条件（如果提供）
    if ($warehouseId) {
        $sql .= " AND inv.warehouse_id = ? ";
        $params = [$productId, $warehouseId];
        $types = "ii";
    } else {
        $params = [$productId];
        $types = "i";
    }

    $sql .= " WHERE pb.product_id = ? ";
    $params[] = $productId;
    $types .= "i";

    // 添加批次ID条件（如果提供）- 确保能查到指定的批次，即使它没有库存
    if ($batchId) {
        $sql .= " OR pb.batch_id = ? ";
        $params[] = $batchId;
        $types .= "i";
    }

    $sql .= " ORDER BY pb.expiration_date ASC";

    error_log("执行SQL查询: $sql, 参数: " . json_encode($params));

    // 使用预处理语句执行查询
    $stmt = $conn->prepare($sql);

    if (!$stmt) {
        throw new Exception("SQL准备失败: " . $conn->error);
    }

    // 绑定参数
    $stmt->bind_param($types, ...$params);

    // 执行查询
    if (!$stmt->execute()) {
        throw new Exception("SQL执行失败: " . $stmt->error);
    }

    // 获取结果
    $result = $stmt->get_result();
    $batches = [];

    while ($row = $result->fetch_assoc()) {
        // 格式化日期
        if ($row['production_date']) {
            $row['production_date'] = date('Y-m-d', strtotime($row['production_date']));
        } else {
            $row['production_date'] = '';
        }

        if ($row['expiration_date']) {
            $row['expiration_date'] = date('Y-m-d', strtotime($row['expiration_date']));
        } else {
            $row['expiration_date'] = '';
        }

        // 添加批次（不再过滤掉没有库存的批次，与根目录下的ajax/get_batches.php保持一致）
        $batches[] = $row;
    }

    // 设置响应
    if (count($batches) > 0) {
        $response['success'] = true;
        $response['batches'] = $batches;
        error_log("找到 " . count($batches) . " 个批次");
    } else {
        $response['message'] = '没有找到可用的批次';
        error_log("未找到批次");
    }

    // 关闭语句
    $stmt->close();
} catch (Exception $e) {
    $response['success'] = false;
    $response['message'] = $e->getMessage();
    error_log('批次获取错误: ' . $e->getMessage());
}

// 输出JSON响应
echo json_encode($response, JSON_UNESCAPED_UNICODE);
