<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 确保$conn变量存在
if (!isset($conn) || $conn === null) {
    die("数据库连接失败");
}

// 初始化消息变量
$message = '';
$messageType = '';

// 检查会话中是否有消息
if (isset($_SESSION['message']) && isset($_SESSION['message_type'])) {
    $message = $_SESSION['message'];
    $messageType = $_SESSION['message_type'];

    // 清除会话消息（只显示一次）
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 从URL获取消息（向后兼容）
if (empty($message) && isset($_GET['message'])) {
    $message = $_GET['message'];
    $messageType = isset($_GET['type']) ? $_GET['type'] : 'info';
}

// 辅助函数：生成订单编号
function generateOrderNumber()
{
    $prefix = 'SO'; // 销售订单前缀
    $date = date('Ymd');
    $random = mt_rand(1000, 9999);
    return $prefix . $date . $random;
}

// 添加辅助函数
function validateOrderData($data)
{
    $errors = [];

    // 验证客户
    if (empty($data['customer_id'])) {
        $errors[] = "请选择客户";
    }

    // 验证订单日期
    if (empty($data['order_date'])) {
        $errors[] = "请选择订单日期";
    } else {
        $date_parts = explode('-', $data['order_date']);
        if (count($date_parts) !== 3 || !checkdate($date_parts[1], $date_parts[2], $date_parts[0])) {
            $errors[] = "订单日期格式不正确";
        }
    }

    // 验证订单状态
    if (empty($data['order_status'])) {
        $errors[] = "请选择订单状态";
    } else {
        $valid_order_statuses = ['pending', 'approved', 'shipping', 'completed', 'cancelled'];
        if (!in_array($data['order_status'], $valid_order_statuses)) {
            $errors[] = "无效的订单状态";
        }
    }

    // 验证支付状态
    if (empty($data['payment_status'])) {
        $errors[] = "请选择支付状态";
    } else {
        $valid_payment_statuses = ['unpaid', 'partial', 'paid'];
        if (!in_array($data['payment_status'], $valid_payment_statuses)) {
            $errors[] = "无效的支付状态";
        }
    }

    // 验证订单明细
    if (empty($data['product_id']) || !is_array($data['product_id'])) {
        $errors[] = "订单明细不能为空";
    } else {
        $itemCount = count($data['product_id']);
        // 确保所有数组的长度一致
        if (count($data['unit_price']) !== $itemCount || count($data['quantity']) !== $itemCount) {
            $errors[] = "订单明细数据不完整";
        }

        // 验证每个商品项
        for ($i = 0; $i < $itemCount; $i++) {
            if (empty($data['product_id'][$i])) {
                $errors[] = "请选择商品";
                break;
            }
            if (!is_numeric($data['unit_price'][$i]) || $data['unit_price'][$i] <= 0) {
                $errors[] = "商品单价必须大于0";
                break;
            }
            if (!is_numeric($data['quantity'][$i]) || $data['quantity'][$i] <= 0) {
                $errors[] = "商品数量必须大于0";
                break;
            }
        }
    }

    return $errors;
}

function createOrder($conn, $data)
{
    try {
        // 记录调试信息
        error_log("开始创建订单: " . json_encode($data));

        // 开始事务
        $conn->begin_transaction();

        // 生成订单号
        $order_number = generateOrderNumber();

        // 准备订单数据
        $sql = "INSERT INTO sales_orders (order_number, customer_id, order_date, delivery_date, 
                order_status, payment_status, total_amount, remark, created_by) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            error_log("准备订单插入SQL失败: " . $conn->error);
            throw new Exception("准备订单插入SQL失败: " . $conn->error);
        }

        // 计算订单总额
        $total_amount = 0;
        for ($i = 0; $i < count($data['product_id']); $i++) {
            $unit_price = $data['unit_price'][$i];
            $quantity = $data['quantity'][$i];
            $discount_rate = isset($data['discount_rate'][$i]) ? $data['discount_rate'][$i] : 0;
            $item_amount = $unit_price * $quantity * (1 - $discount_rate / 100);
            $total_amount += $item_amount;
        }

        // 绑定参数
        $user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : 1;
        $stmt->bind_param(
            "sissssssi",
            $order_number,
            $data['customer_id'],
            $data['order_date'],
            $data['delivery_date'],
            $data['order_status'],
            $data['payment_status'],
            $total_amount,
            $data['remark'],
            $user_id
        );

        // 执行SQL
        if (!$stmt->execute()) {
            error_log("执行订单插入SQL失败: " . $stmt->error);
            throw new Exception("执行订单插入SQL失败: " . $stmt->error);
        }

        // 获取订单ID
        $order_id = $conn->insert_id;
        error_log("订单ID: " . $order_id);

        // 插入订单明细
        $sql = "INSERT INTO sales_order_items (order_id, product_id, unit_price, quantity, 
                discount_rate, item_amount) VALUES (?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            error_log("准备订单明细SQL失败: " . $conn->error);
            throw new Exception("准备订单明细SQL失败: " . $conn->error);
        }

        for ($i = 0; $i < count($data['product_id']); $i++) {
            $product_id = $data['product_id'][$i];
            $unit_price = $data['unit_price'][$i];
            $quantity = $data['quantity'][$i];
            $discount_rate = isset($data['discount_rate'][$i]) ? $data['discount_rate'][$i] : 0;
            $item_amount = $unit_price * $quantity * (1 - $discount_rate / 100);

            $stmt->bind_param("iidddd", $order_id, $product_id, $unit_price, $quantity, $discount_rate, $item_amount);

            if (!$stmt->execute()) {
                error_log("执行订单明细SQL失败: " . $stmt->error);
                throw new Exception("执行订单明细SQL失败: " . $stmt->error);
            }
        }

        // 提交事务
        $conn->commit();
        error_log("订单创建成功: " . $order_id);

        // 设置成功消息
        $_SESSION['message'] = "订单创建成功！";
        $_SESSION['message_type'] = "success";

        return [
            'success' => true,
            'order_id' => $order_id,
            'message' => '订单创建成功'
        ];
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        error_log("订单创建失败: " . $e->getMessage());

        // 设置错误消息
        $_SESSION['message'] = "订单创建失败: " . $e->getMessage();
        $_SESSION['message_type'] = "error";

        return [
            'success' => false,
            'message' => '订单创建失败: ' . $e->getMessage()
        ];
    }
}

function updateOrder($conn, $order_id, $data)
{
    try {
        // 开始事务
        $conn->begin_transaction();

        // 更新主订单
        $sql = "UPDATE sales_orders SET 
                customer_id = ?,
                order_date = ?,
                delivery_date = ?,
                order_status = ?,
                payment_status = ?,
                total_amount = ?,
                remark = ?,
                updated_at = NOW()
                WHERE order_id = ?";

        // 准备SQL语句
        $stmt = $conn->prepare($sql);
        if ($stmt === false) {
            throw new Exception("准备更新订单SQL失败: " . $conn->error);
        }

        // 计算订单总额
        $total_amount = 0;
        for ($i = 0; $i < count($data['product_id']); $i++) {
            $unit_price = $data['unit_price'][$i];
            $quantity = $data['quantity'][$i];
            $discount_rate = isset($data['discount_rate'][$i]) ? $data['discount_rate'][$i] : 0;
            $item_amount = $unit_price * $quantity * (1 - $discount_rate / 100);
            $total_amount += $item_amount;
        }

        // 绑定参数
        $stmt->bind_param(
            "issssdsi",
            $data['customer_id'],
            $data['order_date'],
            $data['delivery_date'],
            $data['order_status'],
            $data['payment_status'],
            $total_amount,
            $data['remark'],
            $order_id
        );

        // 执行SQL语句
        if (!$stmt->execute()) {
            throw new Exception("执行更新订单SQL失败: " . $stmt->error);
        }

        // 删除原有订单明细
        $sql = "DELETE FROM sales_order_items WHERE order_id = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt === false) {
            throw new Exception("准备删除订单明细SQL失败: " . $conn->error);
        }
        $stmt->bind_param("i", $order_id);
        if (!$stmt->execute()) {
            throw new Exception("执行删除订单明细SQL失败: " . $stmt->error);
        }

        // 插入新的订单明细
        $sql = "INSERT INTO sales_order_items (order_id, product_id, unit_price, quantity, 
                discount_rate, item_amount) VALUES (?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            throw new Exception("准备插入订单明细SQL失败: " . $conn->error);
        }

        for ($i = 0; $i < count($data['product_id']); $i++) {
            $product_id = $data['product_id'][$i];
            $unit_price = $data['unit_price'][$i];
            $quantity = $data['quantity'][$i];
            $discount_rate = isset($data['discount_rate'][$i]) ? $data['discount_rate'][$i] : 0;
            $item_amount = $unit_price * $quantity * (1 - $discount_rate / 100);

            $stmt->bind_param("iidddd", $order_id, $product_id, $unit_price, $quantity, $discount_rate, $item_amount);

            if (!$stmt->execute()) {
                throw new Exception("执行插入订单明细SQL失败: " . $stmt->error);
            }
        }

        // 提交事务
        $conn->commit();

        // 设置成功消息
        $_SESSION['message'] = "订单更新成功！";
        $_SESSION['message_type'] = "success";

        return [
            'success' => true,
            'message' => '订单更新成功'
        ];
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        error_log("订单更新失败: " . $e->getMessage());

        // 设置错误消息
        $_SESSION['message'] = "订单更新失败: " . $e->getMessage();
        $_SESSION['message_type'] = "error";

        return [
            'success' => false,
            'message' => '订单更新失败: ' . $e->getMessage()
        ];
    }
}

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 处理订单删除操作
if ($action == 'delete' && isset($_GET['id'])) {
    $order_id = (int)$_GET['id'];

    try {
        // 检查订单是否存在
        $checkSql = "SELECT order_id, order_status FROM sales_orders WHERE order_id = ?";
        $checkStmt = $conn->prepare($checkSql);

        if ($checkStmt) {
            $checkStmt->bind_param("i", $order_id);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult->num_rows > 0) {
                $orderData = $checkResult->fetch_assoc();

                // 检查订单状态，只有待处理的订单才能删除
                if ($orderData['order_status'] != 'pending') {
                    $_SESSION['message'] = '只能删除待处理状态的订单';
                    $_SESSION['message_type'] = 'error';
                    header("Location: index.php?page=order");
                    exit;
                }

                // 开始事务
                $conn->begin_transaction();

                // 先删除订单明细
                $deleteItemsSql = "DELETE FROM sales_order_items WHERE order_id = ?";
                $deleteItemsStmt = $conn->prepare($deleteItemsSql);
                $deleteItemsStmt->bind_param("i", $order_id);
                $deleteItemsStmt->execute();

                // 再删除主订单
                $deleteOrderSql = "DELETE FROM sales_orders WHERE order_id = ?";
                $deleteOrderStmt = $conn->prepare($deleteOrderSql);
                $deleteOrderStmt->bind_param("i", $order_id);

                if ($deleteOrderStmt->execute()) {
                    // 提交事务
                    $conn->commit();

                    // 记录操作日志
                    log_operation($_SESSION['user_id'], '删除销售订单', "删除了订单ID: {$order_id}");

                    $_SESSION['message'] = '销售订单删除成功';
                    $_SESSION['message_type'] = 'success';
                } else {
                    // 回滚事务
                    $conn->rollback();
                    $_SESSION['message'] = '销售订单删除失败: ' . $conn->error;
                    $_SESSION['message_type'] = 'error';
                }
            } else {
                $_SESSION['message'] = '销售订单不存在';
                $_SESSION['message_type'] = 'error';
            }
        } else {
            $_SESSION['message'] = '操作失败: ' . $conn->error;
            $_SESSION['message_type'] = 'error';
        }
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        $_SESSION['message'] = '操作异常: ' . $e->getMessage();
        $_SESSION['message_type'] = 'error';
    }

    header("Location: index.php?page=order");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    error_log("表单提交方法: " . $_SERVER['REQUEST_METHOD']);
    error_log("POST数据: " . print_r($_POST, true));
    error_log("GET数据: " . print_r($_GET, true));
    error_log("当前URL: " . $_SERVER['REQUEST_URI']);
    error_log("来源页面: " . ($_SERVER['HTTP_REFERER'] ?? '未知'));

    $action = isset($_POST['action']) ? $_POST['action'] : '';
    error_log("动作: " . $action);

    if ($action === 'edit') {
        error_log("编辑模式 - POST[order_id]: " . (isset($_POST['order_id']) ? $_POST['order_id'] : '未设置'));
        error_log("编辑模式 - GET[id]: " . (isset($_GET['id']) ? $_GET['id'] : '未设置'));
        if (isset($_POST['order_id'])) {
            error_log("order_id类型: " . gettype($_POST['order_id']));
            error_log("order_id值: " . $_POST['order_id']);
        }
    }

    // 验证数据
    $errors = validateOrderData($_POST);
    if (!empty($errors)) {
        error_log("验证错误: " . print_r($errors, true));
    }

    if (empty($errors)) {
        if ($action === 'add') {
            $result = createOrder($conn, $_POST);
            if ($result['success']) {
                $_SESSION['message'] = $result['message'];
                $_SESSION['message_type'] = 'success';
                header('Location: index.php?page=order');
                exit;
            }
        } else if ($action === 'edit' && isset($_POST['order_id'])) {
            $order_id = intval($_POST['order_id']);
            error_log("编辑订单，ID: " . $order_id);
            error_log("POST[order_id]: " . $_POST['order_id']);

            if ($order_id > 0) {
                error_log("更新订单，ID: " . $order_id);
                $result = updateOrder($conn, $order_id, $_POST);
                if ($result['success']) {
                    $_SESSION['message'] = $result['message'];
                    $_SESSION['message_type'] = 'success';
                    header('Location: index.php?page=order');
                    exit;
                } else {
                    $_SESSION['message'] = $result['message'];
                    $_SESSION['message_type'] = 'error';
                }
            } else {
                error_log("订单ID无效: " . $order_id);
                $_SESSION['message'] = "未指定订单ID";
                $_SESSION['message_type'] = 'error';
            }
        }
    } else {
        $_SESSION['message'] = implode('<br>', $errors);
        $_SESSION['message_type'] = 'error';
    }
}

// 根据操作执行不同的逻辑
switch ($action) {
    case 'add':
        // 显示添加订单表单
        include 'order_form.php';
        break;

    case 'edit':
        error_log("进入编辑模式 - action: edit");
        error_log("GET参数: " . print_r($_GET, true));
        error_log("POST参数: " . print_r($_POST, true));
        error_log("当前URL: " . $_SERVER['REQUEST_URI']);
        error_log("来源页面: " . ($_SERVER['HTTP_REFERER'] ?? '未知'));

        if (isset($_GET['id'])) {
            $order_id = (int)$_GET['id'];
            error_log("编辑模式 - 从URL获取订单ID: " . $order_id);

            // 获取订单信息
            $sql = "SELECT * FROM sales_orders WHERE order_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt) {
                $stmt->bind_param("i", $order_id);
                $stmt->execute();
                $result = $stmt->get_result();

                if ($result->num_rows > 0) {
                    $order = $result->fetch_assoc();
                    error_log("获取到订单数据: " . print_r($order, true));

                    // 获取订单明细
                    $itemSql = "SELECT soi.*, p.product_name 
                                FROM sales_order_items soi 
                                JOIN products p ON soi.product_id = p.product_id WHERE soi.order_id = ?";
                    $itemStmt = $conn->prepare($itemSql);
                    $itemStmt->bind_param("i", $order_id);
                    $itemStmt->execute();
                    $itemResult = $itemStmt->get_result();

                    $orderItems = [];
                    while ($item = $itemResult->fetch_assoc()) {
                        $orderItems[] = $item;
                    }
                    error_log("获取到订单明细: " . print_r($orderItems, true));

                    // 显示编辑表单
                    include 'order_form.php';
                } else {
                    error_log("未找到订单记录");
                    echo '<div class="alert alert-error">未找到订单记录</div>';
                }
            } else {
                error_log("查询失败: " . $conn->error);
                echo '<div class="alert alert-error">查询失败: ' . $conn->error . '</div>';
            }
        } else {
            error_log("未指定订单ID - GET参数不包含id");
            error_log("当前所有GET参数: " . print_r($_GET, true));
            error_log("当前所有POST参数: " . print_r($_POST, true));
            error_log("当前URL: " . $_SERVER['REQUEST_URI']);
            error_log("来源页面: " . ($_SERVER['HTTP_REFERER'] ?? '未知'));
            echo '<div class="alert alert-error">未指定订单ID</div>';
        }
        break;

    case 'view':
        if (isset($_GET['id'])) {
            $order_id = (int)$_GET['id'];

            // 获取订单信息
            $sql = "SELECT so.*, c.customer_name 
                    FROM sales_orders so 
                    LEFT JOIN customers c ON so.customer_id = c.customer_id 
                    WHERE so.order_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt) {
                $stmt->bind_param("i", $order_id);
                $stmt->execute();
                $result = $stmt->get_result();

                if ($result->num_rows > 0) {
                    $viewData = $result->fetch_assoc();

                    // 获取订单明细
                    $itemSql = "SELECT soi.*, p.product_name, p.barcode, p.unit 
                                FROM sales_order_items soi 
                                JOIN products p ON soi.product_id = p.product_id 
                                WHERE soi.order_id = ?";
                    $itemStmt = $conn->prepare($itemSql);
                    $itemStmt->bind_param("i", $order_id);
                    $itemStmt->execute();
                    $itemResult = $itemStmt->get_result();

                    $viewItems = [];
                    while ($item = $itemResult->fetch_assoc()) {
                        $viewItems[] = $item;
                    }

                    // 显示订单详情
                    include 'order_view.php';
                } else {
                    echo '<div class="alert alert-error">未找到订单记录</div>';
                }
            } else {
                echo '<div class="alert alert-error">查询失败: ' . $conn->error . '</div>';
            }
        } else {
            echo '<div class="alert alert-error">未指定订单ID</div>';
        }
        break;

    case 'list':
    default:
        // 获取订单列表
        $page = isset($_GET['listpage']) ? (int)$_GET['listpage'] : 1;
        $limit = 10; // 每页显示10条记录
        $offset = ($page - 1) * $limit;

        // 搜索条件
        $search = isset($_GET['search']) ? trim($_GET['search']) : '';
        $status = isset($_GET['status']) ? trim($_GET['status']) : '';
        $start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
        $end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';

        // 构建查询条件
        $whereClause = "";
        $params = [];
        $types = "";

        if (!empty($search)) {
            $whereClause = "WHERE (so.order_number LIKE ? OR c.customer_name LIKE ?)";
            $searchParam = "%" . $search . "%";
            $params[] = $searchParam;
            $params[] = $searchParam;
            $types .= "ss";
        }

        if (!empty($status)) {
            if (empty($whereClause)) {
                $whereClause = "WHERE so.order_status = ?";
            } else {
                $whereClause .= " AND so.order_status = ?";
            }
            $params[] = $status;
            $types .= "s";
        }

        if (!empty($start_date)) {
            if (empty($whereClause)) {
                $whereClause = "WHERE so.order_date >= ?";
            } else {
                $whereClause .= " AND so.order_date >= ?";
            }
            $params[] = $start_date;
            $types .= "s";
        }

        if (!empty($end_date)) {
            if (empty($whereClause)) {
                $whereClause = "WHERE so.order_date <= ?";
            } else {
                $whereClause .= " AND so.order_date <= ?";
            }
            $params[] = $end_date;
            $types .= "s";
        }

        // 获取总记录数
        $countSql = "SELECT COUNT(*) as total FROM sales_orders so 
                     LEFT JOIN customers c ON so.customer_id = c.customer_id 
                     " . $whereClause;
        $countStmt = $conn->prepare($countSql);

        if (!empty($params)) {
            $countStmt->bind_param($types, ...$params);
        }

        $countStmt->execute();
        $countResult = $countStmt->get_result();
        $totalRecords = $countResult->fetch_assoc()['total'];
        $totalPages = ceil($totalRecords / $limit);

        // 获取订单列表
        $sql = "SELECT so.*, c.customer_name 
                FROM sales_orders so 
                LEFT JOIN customers c ON so.customer_id = c.customer_id 
                {$whereClause} 
                ORDER BY so.order_id DESC LIMIT ?, ?";

        // 添加分页参数
        $params[] = $offset;
        $params[] = $limit;
        $types .= "ii";

        $stmt = $conn->prepare($sql);
        $stmt->bind_param($types, ...$params);
        $stmt->execute();
        $result = $stmt->get_result();

        $orders = [];
        while ($row = $result->fetch_assoc()) {
            $orders[] = $row;
        }

        // 显示订单列表
        include 'order_list.php';
        break;
}

// 辅助函数：获取订单状态中文名称
function getOrderStatusName($status)
{
    $statusMap = [
        'pending' => '待处理',
        'approved' => '已审核',
        'shipping' => '发货中',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

// 辅助函数：获取支付状态中文名称
function getPaymentStatusName($status)
{
    $statusMap = [
        'unpaid' => '未支付',
        'partial' => '部分支付',
        'paid' => '已支付'
    ];
    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

// 辅助函数：获取订单状态对应的样式类
function getOrderStatusBadgeClass($status)
{
    $classMap = [
        'pending' => 'warning',
        'approved' => 'info',
        'shipping' => 'primary',
        'completed' => 'success',
        'cancelled' => 'danger'
    ];
    return isset($classMap[$status]) ? $classMap[$status] : 'secondary';
}
